// SPDX-License-Identifier: GPL-2.0
/*
 * linux/fs/ldiskfs/xattr_hurd.c
 * Handler for extended gnu attributes for the Hurd.
 *
 * Copyright (C) 2001 by Andreas Gruenbacher, <a.gruenbacher@computer.org>
 * Copyright (C) 2020 by Jan (janneke) Nieuwenhuizen, <janneke@gnu.org>
 */

#include <linux/init.h>
#include <linux/string.h>
#include "ldiskfs.h"
#include "xattr.h"

static bool
ldiskfs_xattr_hurd_list(struct dentry *dentry)
{
	return test_opt(dentry->d_sb, XATTR_USER);
}

static int
ldiskfs_xattr_hurd_get(const struct xattr_handler *handler,
		    struct dentry *unused, struct inode *inode,
		    const char *name, void *buffer, size_t size)
{
	if (!test_opt(inode->i_sb, XATTR_USER))
		return -EOPNOTSUPP;

	return ldiskfs_xattr_get(inode, LDISKFS_XATTR_INDEX_HURD,
			      name, buffer, size);
}

static int
ldiskfs_xattr_hurd_set(const struct xattr_handler *handler,
		    struct user_namespace *mnt_userns,
		    struct dentry *unused, struct inode *inode,
		    const char *name, const void *value,
		    size_t size, int flags)
{
	if (!test_opt(inode->i_sb, XATTR_USER))
		return -EOPNOTSUPP;

	return ldiskfs_xattr_set(inode, LDISKFS_XATTR_INDEX_HURD,
			      name, value, size, flags);
}

const struct xattr_handler ldiskfs_xattr_hurd_handler = {
	.prefix	= XATTR_HURD_PREFIX,
	.list	= ldiskfs_xattr_hurd_list,
	.get	= ldiskfs_xattr_hurd_get,
	.set	= ldiskfs_xattr_hurd_set,
};
